llvm/default-to-i586.patch

21 lines
752 B
Diff
Raw Normal View History

Index: llvm-3.3/tools/clang/lib/Driver/Tools.cpp
===================================================================
--- llvm-3.3.orig/tools/clang/lib/Driver/Tools.cpp
+++ llvm-3.3/tools/clang/lib/Driver/Tools.cpp
@@ -1243,12 +1243,12 @@ static const char *getX86TargetCPU(const
if (Triple.getOSName().startswith("netbsd"))
return "i486";
// All x86 devices running Android have core2 as their common
// denominator. This makes a better choice than pentium4.
if (Triple.getEnvironment() == llvm::Triple::Android)
return "core2";
- // Fallback to p4.
- return "pentium4";
+ // Fallback to i586.
+ return "i586";
}
void Clang::AddX86TargetArgs(const ArgList &Args,
@@ -1243,12 +1243,12 @@ static const char *getX86TargetCPU(const
return "i486";
// All x86 devices running Android have core2 as their common
- // denominator. This makes a better choice than pentium4.
+ // denominator. This makes a better choice than i586.
if (Triple.getEnvironment() == llvm::Triple::Android)
return "core2";